// Japper - JAP control via KDE control panel
// Copyright (C) 2004 Josef Spillner <spillner@kde.org>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "japper_config.h"

#include <klocale.h>
#include <kapplication.h>
#include <kconfig.h>
#include <kinputdialog.h>

#include <qlistbox.h>
#include <qlayout.h>
#include <qpushbutton.h>

JapperConfig::JapperConfig(QWidget *parent, const char *name)
: KDialogBase(parent, name, true, i18n("Japper Configuration"),
	KDialogBase::Ok | KDialogBase::Cancel, KDialogBase::Ok, true)
{
	QWidget *root;
	QVBoxLayout *vbox;
	QHBoxLayout *hbox;
	QPushButton *mixauto, *mixadd, *mixdel;

	root = new QWidget(this);
	setMainWidget(root);

	mixes = new QListBox(root);

	mixauto = new QPushButton(i18n("Auto Update"), root);
	mixadd = new QPushButton(i18n("Add Mix"), root);
	mixdel = new QPushButton(i18n("Delete Mix"), root);

	mixauto->setEnabled(false);

	vbox = new QVBoxLayout(root);
	vbox->add(mixes);
	hbox = new QHBoxLayout(vbox);
	hbox->add(mixauto);
	hbox->add(mixadd);
	hbox->add(mixdel);

	connect(mixauto, SIGNAL(clicked()), SLOT(slotAuto()));
	connect(mixadd, SIGNAL(clicked()), SLOT(slotAdd()));
	connect(mixdel, SIGNAL(clicked()), SLOT(slotRemove()));

	KConfig *conf = kapp->config();
	conf->setGroup("Japper");
	m_mixes = conf->readListEntry("Mixes");
	m_mix = conf->readEntry("Mix");

	mixes->insertStringList(m_mixes);
	if(mixes->findItem(m_mix))
		mixes->setSelected(mixes->findItem(m_mix), true);
}

JapperConfig::~JapperConfig()
{
}

void JapperConfig::slotOk()
{
	QStringList list;
	if(mixes->selectedItem())
		m_mix = mixes->selectedItem()->text();
	for(unsigned int i = 0; i < mixes->count(); i++)
		list << mixes->text(i);
	m_mixes = list;

	KConfig *conf = kapp->config();
	conf->setGroup("Japper");
	conf->writeEntry("Mixes", m_mixes);
	conf->writeEntry("Mix", m_mix);
	conf->sync();

	accept();
}

void JapperConfig::slotAuto()
{
}

void JapperConfig::slotAdd()
{
	QString mix = KInputDialog::getText(i18n("Mix hostname:"), i18n("Add Mix"));
	if(!mix.isNull()) mixes->insertItem(mix);
}

void JapperConfig::slotRemove()
{
	if(mixes->selectedItem())
		mixes->takeItem(mixes->selectedItem());
}

