// Japper - JAP control via KDE control panel
// Copyright (C) 2004 Josef Spillner <spillner@kde.org>
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include "japper_tray.h"
#include "japper_config.h"

#include <klocale.h>
#include <kpopupmenu.h>
#include <kapplication.h>
#include <kaboutapplication.h>
#include <kstandarddirs.h>
#include <kconfig.h>
#include <dcopclient.h>
#include <kdebug.h>

#include <qpixmap.h>
#include <qmovie.h>
#include <qtooltip.h>

JapperTray::JapperTray(QWidget *parent, const char *name)
: KSystemTray(parent, name)
{
	contextMenu()->insertItem(i18n("Use JAP"), menuactivate);
	contextMenu()->insertSeparator();
	contextMenu()->insertItem(i18n("Configure"), menuconfigure);
	contextMenu()->insertItem(i18n("About..."), menuabout);

	connect(contextMenu(), SIGNAL(activated(int)), SLOT(slotMenu(int)));

	toggle();

	show();
}

JapperTray::~JapperTray()
{
}

void JapperTray::enableJap()
{
	KConfig *config;

	config = kapp->config();
	config->setGroup("Japper");
	m_mix = config->readEntry("Mix");
	update();
}

void JapperTray::disableJap()
{
	m_mix = QString::null;
	update();
}

void JapperTray::toggle()
{
	KStandardDirs d;

	QString mixstr = m_mix;
	if(mixstr.isNull()) mixstr = i18n("disabled");
	QToolTip::add(this, i18n("JAP control (%1)").arg(mixstr));

	if(!m_mix.isNull())
	{
		setPixmap(d.findResource("data", "japper/japper_tray.png"));
		contextMenu()->setItemChecked(menuactivate, true);
	}
	else
	{
		setPixmap(d.findResource("data", "japper/japper_tray_inactive.png"));
		contextMenu()->setItemChecked(menuactivate, false);
	}
}

void JapperTray::update()
{
	KConfig config("kioslaverc");
	config.setGroup("Proxy Settings");
	if(!m_mix.isNull())
	{
		config.writeEntry("ProxyType", 1);
		config.writeEntry("httpProxy", "http://localhost:8080");
	}
	else
	{
		config.writeEntry("ProxyType", 0);
		config.writeEntry("httpProxy", "");
	}
	config.sync();

	toggle();

	updateInstances();
}

void JapperTray::updateInstances()
{
	DCOPClient *c;
	QByteArray data, reply;
	QCString replytype;
	QCStringList apps;
	bool b1, b2, b3;

	c = kapp->dcopClient();
	b1 = c->attach();

	apps = c->registeredApplications();
	for(QCStringList::Iterator it = apps.begin(); it != apps.end(); it++)
	{
		kdDebug() << (*it) << endl;
		if(QString(*it).startsWith("konqueror"))
		{
			//b2 = c->call((*it), "default", "reparseConfiguration", data, replytype, reply, true, 300);
			b2 = c->send((*it), "default", "reparseConfiguration", data);
			kdDebug() << "INSTANCE? " << QString(*it) << " " << b2 << endl;
			kdDebug() << "REPLY: " << replytype << " " << endl;
			kdDebug() << QString(reply) << endl;
		}
	}

	b3 = c->detach();

	kdDebug() << "SUCCESS? " << b1 << "-" << b3 << endl;
}

void JapperTray::slotMenu(int id)
{
	JapperConfig config;

	switch(id)
	{
		case menuactivate:
			if(contextMenu()->isItemChecked(menuactivate)) disableJap();
			else enableJap();
			break;
		case menuconfigure:
			config.exec();
			break;
		case menuabout:
			const KAboutData *aboutdata = kapp->aboutData();
			KAboutApplication aboutdialog(aboutdata, this);
			aboutdialog.exec();
			break;
	}
}

